==> haskell-yesod-1.6.0-49-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod
version: 1.6.0
id: yesod-1.6.0-1VrN6o8FinI76uao0B49mt
key: yesod-1.6.0-1VrN6o8FinI76uao0B49mt
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod>
category: Web, Yesod
abi: a3c29a364f04d6a0e914c6fa9be27aac
exposed: True
exposed-modules:
    Yesod Yesod.Default.Config Yesod.Default.Config2
    Yesod.Default.Handlers Yesod.Default.Main Yesod.Default.Util
import-dirs: /usr/lib/ghc-8.4.3/site-local/yesod-1.6.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/yesod-1.6.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/yesod-1.6.0
hs-libraries: HSyesod-1.6.0-1VrN6o8FinI76uao0B49mt
depends:
    aeson-1.3.1.1-TT45dpTFlI3IDS4gOrl3y base-4.11.1.0
    blaze-html-0.9.1.1-20cHaEyBGNsGxpPmCtOdMq
    blaze-markup-0.8.2.1-FFkiru1HsegAfMrnqJMDug bytestring-0.10.8.2
    conduit-1.3.0.3-66nd3O923iS53T8SI1MATt
    data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j directory-1.3.1.5
    fast-logger-2.4.11-6LKqhJmZGwUIa706cRTW3e
    monad-logger-0.3.28.5-DbEbvv2YHxAh1lF2yzVCT
    resourcet-1.2.1-BNyr3sQ3rlV9LHFNVRp8Be
    shakespeare-2.0.15-AYGkoAAVr8N3J71KcHfMWO
    streaming-commons-0.2.0.0-BR38PtjwTMX5cYZgzsA3qo
    template-haskell-2.13.0.0 text-1.2.3.0 transformers-0.5.5.0
    unix-2.7.2.2 unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
    wai-3.2.1.2-FYNUSCGVi1MEtdQVVwNIxx
    wai-extra-3.0.22.1-KJlyHFpeYikDUiMv1Gg7on
    wai-logger-2.3.2-8wneV8Zq5jX32yd00otpUr
    warp-3.2.22-HY9tYerhh1X6Gd8jArtQ3A
    yaml-0.8.31-8lmUQZqhgVSG966TPhCNOy
    yesod-core-1.6.5-32xOk1nCBu0I44htNBtOl2
    yesod-form-1.6.1-EJV4lyc88HD5Djldxa5JJM
    yesod-persistent-1.6.0-Gk1AuSb4kF921kTV2FZbJO
abi-depends: aeson-1.3.1.1-TT45dpTFlI3IDS4gOrl3y=07d229e9fe1ca7309e20349a237239ed
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             blaze-html-0.9.1.1-20cHaEyBGNsGxpPmCtOdMq=7047caae57386baf49e8a9f0b929d8b4
             blaze-markup-0.8.2.1-FFkiru1HsegAfMrnqJMDug=18a52ecde9bf04c66bdf9a0cefc08348
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             conduit-1.3.0.3-66nd3O923iS53T8SI1MATt=d2e06181920a4035b53bbf7f067a9d71
             data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j=64b4bc7e44050b1acf530e79a106effe
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             fast-logger-2.4.11-6LKqhJmZGwUIa706cRTW3e=74f385e9dd50fadd4b5101789b2372bf
             monad-logger-0.3.28.5-DbEbvv2YHxAh1lF2yzVCT=d96ebb6eedd950e96670a90e52539649
             resourcet-1.2.1-BNyr3sQ3rlV9LHFNVRp8Be=aed379ba96ef65280506356d2c555107
             shakespeare-2.0.15-AYGkoAAVr8N3J71KcHfMWO=2ba329459f9f7720efac369c1b63f65b
             streaming-commons-0.2.0.0-BR38PtjwTMX5cYZgzsA3qo=49dc86a0f1ca19cf6c8c8dcacc229332
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             unix-2.7.2.2=5200b6eb79607eed6537538f20d679bf
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
             wai-3.2.1.2-FYNUSCGVi1MEtdQVVwNIxx=a10b0b451ac20f27f6160db52b013dec
             wai-extra-3.0.22.1-KJlyHFpeYikDUiMv1Gg7on=a72ffbe2bfa51351bf53d691c5b04e1a
             wai-logger-2.3.2-8wneV8Zq5jX32yd00otpUr=27202fb50a9e9bfc25ee18609d6e791b
             warp-3.2.22-HY9tYerhh1X6Gd8jArtQ3A=6e2c18e816108018f85e88f517ed2b28
             yaml-0.8.31-8lmUQZqhgVSG966TPhCNOy=0c0d3b06ec48a30f67e50d3914487783
             yesod-core-1.6.5-32xOk1nCBu0I44htNBtOl2=1ea912c8bb8ceac914485e60e466bdfb
             yesod-form-1.6.1-EJV4lyc88HD5Djldxa5JJM=135b6347de377258ea65db63c79d2dd2
             yesod-persistent-1.6.0-Gk1AuSb4kF921kTV2FZbJO=d6b9e86e8413c169df7c8b72a9d51648
haddock-interfaces: /usr/share/doc/haskell-yesod/html/yesod.haddock
haddock-html: /usr/share/doc/haskell-yesod/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-1.6.0-50-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod
version: 1.6.0
id: yesod-1.6.0-AmifI93gG0b2Wu4DCSjPnk
key: yesod-1.6.0-AmifI93gG0b2Wu4DCSjPnk
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod>
category: Web, Yesod
abi: bffaf33e59a84de61874f252ee25320f
exposed: True
exposed-modules:
    Yesod Yesod.Default.Config Yesod.Default.Config2
    Yesod.Default.Handlers Yesod.Default.Main Yesod.Default.Util
import-dirs: /usr/lib/ghc-8.4.3/site-local/yesod-1.6.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/yesod-1.6.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/yesod-1.6.0
hs-libraries: HSyesod-1.6.0-AmifI93gG0b2Wu4DCSjPnk
depends:
    aeson-1.3.1.1-TT45dpTFlI3IDS4gOrl3y base-4.11.1.0
    blaze-html-0.9.1.1-20cHaEyBGNsGxpPmCtOdMq
    blaze-markup-0.8.2.1-FFkiru1HsegAfMrnqJMDug bytestring-0.10.8.2
    conduit-1.3.0.3-66nd3O923iS53T8SI1MATt
    data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j directory-1.3.1.5
    fast-logger-2.4.11-6LKqhJmZGwUIa706cRTW3e
    monad-logger-0.3.28.5-Le3NyXl6lgo8CJsdX6ybpJ
    resourcet-1.2.1-BNyr3sQ3rlV9LHFNVRp8Be
    shakespeare-2.0.15-AYGkoAAVr8N3J71KcHfMWO
    streaming-commons-0.2.0.0-JgIXAI1RxNy4PvXEKvDakK
    template-haskell-2.13.0.0 text-1.2.3.0 transformers-0.5.5.0
    unix-2.7.2.2 unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
    wai-3.2.1.2-BZpOn5OSZorCibTMFlKxoh
    wai-extra-3.0.22.1-7QmLNxSLju21lmv1opY1EV
    wai-logger-2.3.2-FCFgsbDcNYEKCNk20vjb4i
    warp-3.2.22-HD9A29cf5w3Jl1EwrKzX5W
    yaml-0.8.31-8lmUQZqhgVSG966TPhCNOy
    yesod-core-1.6.5-5JtbZKSxzjqR6tD6z8kSo
    yesod-form-1.6.1-2CfbDLkP7qZCU0O059WGhZ
    yesod-persistent-1.6.0-9b7NF3qXaxFizGE8ndBR4
abi-depends: aeson-1.3.1.1-TT45dpTFlI3IDS4gOrl3y=07d229e9fe1ca7309e20349a237239ed
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             blaze-html-0.9.1.1-20cHaEyBGNsGxpPmCtOdMq=7047caae57386baf49e8a9f0b929d8b4
             blaze-markup-0.8.2.1-FFkiru1HsegAfMrnqJMDug=18a52ecde9bf04c66bdf9a0cefc08348
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             conduit-1.3.0.3-66nd3O923iS53T8SI1MATt=d2e06181920a4035b53bbf7f067a9d71
             data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j=64b4bc7e44050b1acf530e79a106effe
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             fast-logger-2.4.11-6LKqhJmZGwUIa706cRTW3e=74f385e9dd50fadd4b5101789b2372bf
             monad-logger-0.3.28.5-Le3NyXl6lgo8CJsdX6ybpJ=1cc2cf87695ad5c5895a81aa46ff58bd
             resourcet-1.2.1-BNyr3sQ3rlV9LHFNVRp8Be=aed379ba96ef65280506356d2c555107
             shakespeare-2.0.15-AYGkoAAVr8N3J71KcHfMWO=2ba329459f9f7720efac369c1b63f65b
             streaming-commons-0.2.0.0-JgIXAI1RxNy4PvXEKvDakK=12e263684b9335842044eb218cab9a12
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             unix-2.7.2.2=5200b6eb79607eed6537538f20d679bf
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
             wai-3.2.1.2-BZpOn5OSZorCibTMFlKxoh=3c531a9c9dceb5cf3884617d81bc336d
             wai-extra-3.0.22.1-7QmLNxSLju21lmv1opY1EV=b4aa7ea7b4308af6e795a2fe46a71976
             wai-logger-2.3.2-FCFgsbDcNYEKCNk20vjb4i=cde76aa08f59d955e2ab0a4812969f6d
             warp-3.2.22-HD9A29cf5w3Jl1EwrKzX5W=1d9baf1f171c173416edccd3cf032c07
             yaml-0.8.31-8lmUQZqhgVSG966TPhCNOy=0c0d3b06ec48a30f67e50d3914487783
             yesod-core-1.6.5-5JtbZKSxzjqR6tD6z8kSo=804195ab12393543e6e312d52e756424
             yesod-form-1.6.1-2CfbDLkP7qZCU0O059WGhZ=4f8f81aa9020ea2355219e777e620329
             yesod-persistent-1.6.0-9b7NF3qXaxFizGE8ndBR4=536f3d2535488e3e326cccd9cb04161a
haddock-interfaces: /usr/share/doc/haskell-yesod/html/yesod.haddock
haddock-html: /usr/share/doc/haskell-yesod/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
